[edk2-devel] [PATCH 07/79] EmulatorPkg/Win: Fix various typos

Philippe Mathieu-Daudé via Groups.Io philmd=redhat.com at groups.io
Tue Dec 3 16:14:50 UTC 2019


From: Antoine Coeur <coeur at gmx.fr>

Fix various typos in comments and documentation.

Cc: Jordan Justen <jordan.l.justen at intel.com>
Cc: Andrew Fish <afish at apple.com>
Cc: Ray Ni <ray.ni at intel.com>
Reviewed-by: Philippe Mathieu-Daude <philmd at redhat.com>
Signed-off-by: Philippe Mathieu-Daude <philmd at redhat.com>
---
 EmulatorPkg/Win/Host/WinGop.h        |  2 +-
 EmulatorPkg/Win/Host/WinHost.h       |  2 +-
 EmulatorPkg/Win/Host/WinBlockIo.c    |  4 ++--
 EmulatorPkg/Win/Host/WinFileSystem.c |  2 +-
 EmulatorPkg/Win/Host/WinGopInput.c   |  4 ++--
 EmulatorPkg/Win/Host/WinGopScreen.c  | 14 +++++++-------
 EmulatorPkg/Win/Host/WinHost.c       | 10 +++++-----
 7 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/EmulatorPkg/Win/Host/WinGop.h b/EmulatorPkg/Win/Host/WinGop.h
index 5943ca93b22f..7a8f01a37c92 100644
--- a/EmulatorPkg/Win/Host/WinGop.h
+++ b/EmulatorPkg/Win/Host/WinGop.h
@@ -78,7 +78,7 @@ typedef struct {
   UINT32                        Width;
   UINT32                        Height;
   //
-  // This screen is used to redraw the scree when windows events happen. It's
+  // This screen is used to redraw the screen when windows events happen. It's
   // updated in the main thread and displayed in the windows thread.
   //
   BITMAPV4HEADER                *VirtualScreenInfo;
diff --git a/EmulatorPkg/Win/Host/WinHost.h b/EmulatorPkg/Win/Host/WinHost.h
index 185d864986ff..0e52c003fc63 100644
--- a/EmulatorPkg/Win/Host/WinHost.h
+++ b/EmulatorPkg/Win/Host/WinHost.h
@@ -82,7 +82,7 @@ Arguments:
   SecCorePe32File         - SEC Core PE32
 
 Returns:
-  Success means control is transfered and thus we should never return
+  Success means control is transferred and thus we should never return
 
 --*/
 ;
diff --git a/EmulatorPkg/Win/Host/WinBlockIo.c b/EmulatorPkg/Win/Host/WinBlockIo.c
index 5ccd17388ea8..715d0c26cdbc 100644
--- a/EmulatorPkg/Win/Host/WinBlockIo.c
+++ b/EmulatorPkg/Win/Host/WinBlockIo.c
@@ -346,7 +346,7 @@ WinNtBlockIoReadBlocks (
                                 the Event is NULL.
   @retval EFI_WRITE_PROTECTED   The device can not be written to.
   @retval EFI_NO_MEDIA          There is no media in the device.
-  @retval EFI_MEDIA_CHNAGED     The MediaId does not matched the current device.
+  @retval EFI_MEDIA_CHANGED     The MediaId does not match the current device.
   @retval EFI_DEVICE_ERROR      The device reported an error while performing the write.
   @retval EFI_BAD_BUFFER_SIZE   The Buffer was not a multiple of the block size of the device.
   @retval EFI_INVALID_PARAMETER The write request contains LBAs that are not valid,
@@ -411,7 +411,7 @@ WinNtBlockIoWriteBlocks (
   @retval EFI_SUCCESS          The flush request was queued if Event is not NULL.
                                All outstanding data was written correctly to the
                                device if the Event is NULL.
-  @retval EFI_DEVICE_ERROR     The device reported an error while writting back
+  @retval EFI_DEVICE_ERROR     The device reported an error while writing back
                                the data.
   @retval EFI_WRITE_PROTECTED  The device cannot be written to.
   @retval EFI_NO_MEDIA         There is no media in the device.
diff --git a/EmulatorPkg/Win/Host/WinFileSystem.c b/EmulatorPkg/Win/Host/WinFileSystem.c
index aab926889e0a..f6b06b1c9204 100644
--- a/EmulatorPkg/Win/Host/WinFileSystem.c
+++ b/EmulatorPkg/Win/Host/WinFileSystem.c
@@ -391,7 +391,7 @@ GetNextFileNameToken (
   If FileName contains only a single L'\', return TRUE.
   If FileName contains two adjacent L'\', return FALSE.
   If FileName conatins L'/' , return FALSE.
-  If FielName contains more than two dots seperated with other FileName characters
+  If FileName contains more than two dots separated with other FileName characters
   by L'\', return FALSE. For example, L'.\...\filename.txt' is invalid path name. But L'..TwoDots\filename.txt' is valid path name.
 
   @param FileName  The File Name String to check.
diff --git a/EmulatorPkg/Win/Host/WinGopInput.c b/EmulatorPkg/Win/Host/WinGopInput.c
index 312a549847c5..6ae7aa4c371b 100644
--- a/EmulatorPkg/Win/Host/WinGopInput.c
+++ b/EmulatorPkg/Win/Host/WinGopInput.c
@@ -300,7 +300,7 @@ WinNtWndGetKey (
 
   Routine Description:
     Reads the next keystroke from the input device. The WaitForKey Event can
-    be used to test for existance of a keystroke via WaitForEvent () call.
+    be used to test for existence of a keystroke via WaitForEvent () call.
 
   Arguments:
     Private    - The private structure of WinNt Gop device.
@@ -309,7 +309,7 @@ WinNtWndGetKey (
 
   Returns:
     EFI_SUCCESS           - The keystroke information was returned.
-    EFI_NOT_READY         - There was no keystroke data availiable.
+    EFI_NOT_READY         - There was no keystroke data available.
     EFI_DEVICE_ERROR      - The keystroke information was not returned due to
                             hardware errors.
     EFI_INVALID_PARAMETER - KeyData is NULL.
diff --git a/EmulatorPkg/Win/Host/WinHost.c b/EmulatorPkg/Win/Host/WinHost.c
index 62a89f7617af..cfee156b27b4 100644
--- a/EmulatorPkg/Win/Host/WinHost.c
+++ b/EmulatorPkg/Win/Host/WinHost.c
@@ -48,7 +48,7 @@ UINTN                                     gFdInfoCount = 0;
 NT_FD_INFO                                *gFdInfo;
 
 //
-// Array that supports seperate memory rantes.
+// Array that supports separate memory ranges.
 //  The memory ranges are set by PcdWinNtMemorySizeForSecMain.
 //  The number of array elements is allocated base on parsing
 //  PcdWinNtMemorySizeForSecMain value and the memory is never freed.
@@ -105,7 +105,7 @@ WinPeiAutoScan (
 
 Routine Description:
   Return the FD Size and base address. Since the FD is loaded from a
-  file into host memory only the SEC will know it's address.
+  file into host memory only the SEC will know its address.
 
 Arguments:
   Index  - Which FD, starts at zero.
@@ -273,7 +273,7 @@ Arguments:
 Returns:
   EFI_SUCCESS      - The file was opened and mapped.
   EFI_NOT_FOUND    - FileName was not found in the current directory
-  EFI_DEVICE_ERROR - An error occured attempting to map the opened file
+  EFI_DEVICE_ERROR - An error occurred attempting to map the opened file
 
 --*/
 {
@@ -625,7 +625,7 @@ Arguments:
   SecCorePe32File         - SEC Core PE32
 
 Returns:
-  Success means control is transfered and thus we should never return
+  Success means control is transferred and thus we should never return
 
 --*/
 {
@@ -993,7 +993,7 @@ PeCoffLoaderRelocateImageExtraAction (
   //  the *.dll file as a library using Windows* APIs. This allows
   //  source level debug. The image is still loaded and relocated
   //  in the Framework memory space like on a real system (by the code above),
-  //  but the entry point points into the DLL loaded by the code bellow.
+  //  but the entry point points into the DLL loaded by the code below.
   //
 
   DllEntryPoint = NULL;
diff --git a/EmulatorPkg/Win/Host/WinGopScreen.c b/EmulatorPkg/Win/Host/WinGopScreen.c
index fa34596497f8..74011e225e30 100644
--- a/EmulatorPkg/Win/Host/WinGopScreen.c
+++ b/EmulatorPkg/Win/Host/WinGopScreen.c
@@ -297,7 +297,7 @@ WinNtWndSize (
   @param  X                      X location on graphics screen.
   @param  Y                      Y location on the graphics screen.
   @param  Width                  Width of BltBuffer.
-  @param  Height                 Hight of BltBuffer
+  @param  Height                 Height of BltBuffer
   @param  BltOperation           Operation to perform on BltBuffer and video memory
   @param  BltBuffer              Buffer containing data to blt into video buffer.
                                  This  buffer has a size of
@@ -311,7 +311,7 @@ WinNtWndSize (
 
   @retval EFI_SUCCESS            The palette is updated with PaletteArray.
   @retval EFI_INVALID_PARAMETER  BltOperation is not valid.
-  @retval EFI_DEVICE_ERROR       A hardware error occured writting to the video
+  @retval EFI_DEVICE_ERROR       A hardware error occurred writing to the video
                                  buffer.
 
 **/
@@ -593,11 +593,11 @@ WinNtGopThreadWindowProc (
 
 
 /**
-  This thread simulates the end of WinMain () aplication. Each Winow nededs
-  to process it's events. The messages are dispatched to
+  This thread simulates the end of WinMain () application. Each Window needs
+  to process its events. The messages are dispatched to
   WinNtGopThreadWindowProc ().
-  Be very careful sine WinNtGopThreadWinMain () and WinNtGopThreadWindowProc ()
-  are running in a seperate thread. We have to do this to process the events.
+  Be very careful since WinNtGopThreadWinMain () and WinNtGopThreadWindowProc ()
+  are running in a separate thread. We have to do this to process the events.
 
   @param  lpParameter            Handle of window to manage.
 
@@ -679,7 +679,7 @@ WinNtGopThreadWinMain (
                             );
 
   //
   // The reset of this thread is the standard winows program. We need a sperate
   // thread since we must process the message loop to make windows act like
   // windows.
   //
@@ -679,7 +679,7 @@ WinNtGopThreadWinMain (
 
   //
-  // The reset of this thread is the standard winows program. We need a sperate
+  // The reset of this thread is the standard windows program. We need a separate
   // thread since we must process the message loop to make windows act like
   // windows.
-- 
2.21.0


-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.

View/Reply Online (#51612): https://edk2.groups.io/g/devel/message/51612
Mute This Topic: https://groups.io/mt/65773048/1813853
Group Owner: devel+owner at edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub  [edk2-devel-archive at redhat.com]
-=-=-=-=-=-=-=-=-=-=-=-





More information about the edk2-devel-archive mailing list